@@ -98,12 +98,16 @@ def get_closest(word, possibilities, cutoff=0.6, fallback_to_first=True):
 
 
 def get_close_matches(word, possibilities, n=None, cutoff=0.6):
-    """Overrides `difflib.get_close_match` to controle argument `n`."""
+    """Overrides `difflib.get_close_match` to control argument `n`."""
     if n is None:
         n = settings.num_close_matches
     return difflib_get_close_matches(word, possibilities, n, cutoff)
 
 
+def include_path_in_search(path):
+    return not any(path.startswith(x) for x in settings.excluded_search_path_prefixes)
+
+
 @memoize
 def get_all_executables():
     from thefuck.shells import shell
@@ -118,7 +122,8 @@ def get_all_executables():
     tf_entry_points = ['thefuck', 'fuck']
 
     bins = [exe.name.decode('utf8') if six.PY2 else exe.name
-            for path in os.environ.get('PATH', '').split(':')
+            for path in os.environ.get('PATH', '').split(os.pathsep)
+            if include_path_in_search(path)
             for exe in _safe(lambda: list(Path(path).iterdir()), [])
             if not _safe(exe.is_dir, True)
             and exe.name not in tf_entry_points]
